@@ -11,7 +11,7 @@ from typing import Sequence
 
 import numpy
 
-from apppath import ensure_existence
+from warg import ensure_existence
 from draugr.numpy_utilities.datasets.splitting import SplitEnum
 from draugr.numpy_utilities.signal_utilities.signal_statistics import root_mean_square
 from draugr.numpy_utilities.signal_utilities.truncation import min_length_truncate_batch
