@@ -19,8 +19,7 @@ def mean_square(x: numpy.ndarray) -> numpy.ndarray:
     * x: signal vector
     output
     ------
-    * Mean square of `x`.
-    """
+    * Mean square of `x`."""
 
     return numpy.mean(numpy.abs(x) ** 2)
 
@@ -29,7 +28,6 @@ def root_mean_square(x: numpy.ndarray) -> numpy.ndarray:
     """Root Mean Square value of signal `x`.
     input
     -----
-    * x: signal vector
-    """
+    * x: signal vector"""
 
     return numpy.sqrt(mean_square(x))  # faster than **.5
