@@ -10,10 +10,24 @@ __all__ = ["num_channels", "is_singular_channel", "to_color"]
 
 
 def num_channels(image) -> int:
+    """
+
+    :param image:
+    :type image:
+    :return:
+    :rtype:
+    """
     return image.shape[-1] if image.ndim == 3 else 1
 
 
 def is_singular_channel(image) -> bool:
+    """
+
+    :param image:
+    :type image:
+    :return:
+    :rtype:
+    """
     return num_channels(image) == 1
 
 
@@ -21,12 +35,10 @@ def to_color(image, conversion: ColorConversionEnum = ColorConversionEnum.gray2b
     """
     convert from the default bgr cv2 format to gray, using a single component
 
+    :param conversion:
+    :type conversion:
     :param image:
     :type image:
-    :param component:
-    :type component:
-    :param to_gray_method:
-    :type to_gray_method:
     :return:
     :rtype:
     """
