@@ -1,5 +1,6 @@
 import queue
 import threading
+from typing import Sequence, MutableMapping
 
 __all__ = ["Skipper"]
 
@@ -33,7 +34,7 @@ class Skipper:
             pass
         self.thread.join()
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args: Sequence, **kwargs: MutableMapping):
         while not self.Q.empty():
             self.Q.get_nowait()
         self.Q.put((args, kwargs))
@@ -45,51 +46,59 @@ if __name__ == "__main__":
         """description"""
         import time
 
-        def worker(wid):
+        def worker(wid, wait_time_sec=1):
             """
 
             :param wid:
             :type wid:
             """
             print(f"Worker {wid} Start")
-            time.sleep(1)
+            time.sleep(wait_time_sec)
             print(f"Worker {wid} END")
 
         S = Skipper(worker)
         S(1)
         time.sleep(0.1)
+        print("next_job")
         S(2)
         time.sleep(0.1)
+        print("next_job")
         S(3)
         time.sleep(4)
+        print("next_job")
         S(4)
         time.sleep(0.2)
+        print("next_job")
         S(5)
         time.sleep(0.2)
+        print("next_job")
         S(6)
         time.sleep(0.2)
+        print("next_job")
         S(7)
         time.sleep(4)
+        print("Deadline")
         S.stop()
 
     def yhhgsad2y():
         """description"""
         import time
 
-        def worker(wid):
+        def worker(wid, wait_time_sec=1):
             """
 
             :param wid:
             :type wid:
             """
             print(f"Worker {wid} Start")
-            time.sleep(1)
+            time.sleep(wait_time_sec)
             print(f"Worker {wid} END")
 
         S = Skipper(worker)
         S(1)
         time.sleep(4)
+        print("Deadline")
         S.stop()
 
-    # yhhgsady()
-    yhhgsad2y()
+    yhhgsady()
+    # yhhgsad2y()
