@@ -17,7 +17,7 @@ from warg import indent_lines
 
 
 class Architecture(nn.Module, ABC):
-    """ """
+    """description"""
 
     @drop_unused_kws
     def __init__(self, input_shape: Sequence[int], output_shape: Sequence[int]):
@@ -42,6 +42,11 @@ class Architecture(nn.Module, ABC):
         return self._output_shape
 
     def sample_input(self) -> Any:
+        """
+
+        :return:
+        :rtype:
+        """
         return torch.empty(1, *self.input_shape, device="cpu")
 
     def __repr__(self):
