@@ -26,13 +26,13 @@ class CategoricalDataset(SupervisedDataset):
     @property
     @abstractmethod
     def categories(self) -> OrderedSet[str]:
-        """ """
+        """description"""
         raise NotImplementedError
 
     def idx_to_str(self, idx: Sequence[int]) -> Sequence[str]:
-        """ """
+        """description"""
         return self.categories[idx]
 
     def str_to_idx(self, s: str) -> int:
-        """ """
+        """description"""
         return self.categories.index(s)
