@@ -26,7 +26,7 @@ def find_n_misclassified(
     n: int = 10,
     device: torch.device = global_torch_device(),
 ) -> None:
-    """ """
+    """description"""
     j = 0
     num_samples = len(evaluation_loader)
     with TorchEvalSession(model):
